import robocop.reports
from robocop.version import __version__


class RobocopVersionReport(robocop.reports.ComparableReport):
    """
    **Report name**: ``version``

    Report that returns Robocop version.

    Example::

        Report generated by Robocop version: 2.0.2
    """

    def __init__(self, compare_runs):
        self.name = "version"
        self.description = "Returns Robocop version"
        super().__init__(compare_runs)

    def persist_result(self):
        return {"generated_with": __version__}

    def get_report(self, prev_results) -> str:
        summary = f"\nReport generated by Robocop version: {__version__}"
        if self.compare_runs and prev_results and prev_results["generated_with"] != __version__:
            summary += f". Previous results generated by Robocop version: {prev_results['generated_with']}"
        return summary
